@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
-use lib '../../../../../..';
+use rlib '../../../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Set::Auto::Eval;
 use Devel::Trepan::CmdProcessor::Command::Subcmd::Subsubcmd;
